@@ -1,22 +1,21 @@
 /**
- * Copyright (c) HashiCorp, Inc.
+ * Copyright IBM Corp. 2016, 2025
  * SPDX-License-Identifier: BUSL-1.1
  */
 
 import Route from '@ember/routing/route';
-import { service } from '@ember/service';
+import AuthMethodForm from 'vault/forms/auth/method';
 
 import type { ModelFrom } from 'vault/vault/route';
-import type Store from '@ember-data/store';
 
 export type AuthEnableModel = ModelFrom<VaultClusterSettingsAuthEnableRoute>;
 
 export default class VaultClusterSettingsAuthEnableRoute extends Route {
-  @service declare readonly store: Store;
-
   model() {
-    const authMethod = this.store.createRecord('auth-method');
-    authMethod.set('config', this.store.createRecord('mount-config'));
-    return authMethod;
+    const defaults = {
+      config: { listing_visibility: false },
+      user_lockout_config: {},
+    };
+    return new AuthMethodForm(defaults, { isNew: true });
   }
 }
