@@ -1,5 +1,5 @@
 /**
- * Copyright (c) HashiCorp, Inc.
+ * Copyright IBM Corp. 2016, 2025
  * SPDX-License-Identifier: BUSL-1.1
  */
 
@@ -18,6 +18,12 @@ export interface FieldOptions {
   sensitive?: boolean;
   noCopy?: boolean;
   docLink?: string;
+  helpText?: string;
+  helperTextDisabled?: string;
+  helperTextEnabled?: string;
+  placeholder?: string;
+  noDefault?: boolean;
+  isSectionHeader?: boolean;
 }
 
 export default class FormField {
