@@ -1,5 +1,5 @@
 /**
- * Copyright (c) HashiCorp, Inc.
+ * Copyright IBM Corp. 2016, 2025
  * SPDX-License-Identifier: BUSL-1.1
  */
 
@@ -9,7 +9,7 @@ import { setupApplicationTest } from 'vault/tests/helpers';
 import { login } from 'vault/tests/helpers/auth/auth-helpers';
 import { deleteEngineCmd, mountEngineCmd, runCmd, tokenWithPolicyCmd } from 'vault/tests/helpers/commands';
 import { personas } from 'vault/tests/helpers/kv/policy-generator';
-import { clearRecords, deleteLatestCmd, writeVersionedSecret } from 'vault/tests/helpers/kv/kv-run-commands';
+import { deleteLatestCmd, writeVersionedSecret } from 'vault/tests/helpers/kv/kv-run-commands';
 import { setupControlGroup } from 'vault/tests/helpers/control-groups';
 import { click, currentRouteName, currentURL, waitUntil, visit } from '@ember/test-helpers';
 import { PAGE } from 'vault/tests/helpers/kv/kv-selectors';
@@ -42,8 +42,8 @@ module('Acceptance | kv-v2 workflow | delete, undelete, destroy', function (hook
   hooks.beforeEach(async function () {
     this.store = this.owner.lookup('service:store');
     this.backend = `kv-delete-${uuidv4()}`;
-    this.secretPath = 'bad_secret';
-    this.nestedSecretPath = 'app/nested/bad_secret';
+    this.secretPath = 'bad-secret';
+    this.nestedSecretPath = 'app/nested/bad-secret';
     await login();
     await runCmd(mountEngineCmd('kv-v2', this.backend), false);
     await writeVersionedSecret(this.backend, this.secretPath, 'foo', 'bar', 4);
@@ -63,9 +63,7 @@ module('Acceptance | kv-v2 workflow | delete, undelete, destroy', function (hook
       // patch actions exist before/after deletion can run on both CE and ent repos
       this.version = this.owner.lookup('service:version').type = 'enterprise';
       const token = await runCmd(makeToken('admin', this.backend, personas.admin));
-      await login(token);
-      clearRecords(this.store);
-      return;
+      return login(token);
     });
     test('can delete and undelete the latest secret version (a)', async function (assert) {
       assert.expect(21);
@@ -171,8 +169,8 @@ module('Acceptance | kv-v2 workflow | delete, undelete, destroy', function (hook
     });
 
     test('can permanently delete all secret versions (a)', async function (assert) {
-      await writeVersionedSecret(this.backend, 'nu_ke', 'foo', 'bar', 2);
-      await visit(`/vault/secrets/${this.backend}/kv/nu_ke/metadata`);
+      await writeVersionedSecret(this.backend, 'nuke', 'foo', 'bar', 2);
+      await visit(`/vault/secrets/${this.backend}/kv/nuke/metadata`);
       assert.dom(PAGE.metadata.deleteMetadata).hasText('Permanently delete', 'shows delete metadata button');
       // delete flow
       await click(PAGE.metadata.deleteMetadata);
@@ -190,13 +188,11 @@ module('Acceptance | kv-v2 workflow | delete, undelete, destroy', function (hook
     hooks.beforeEach(async function () {
       // create and delete a secret as root user
       await login();
-      await writeVersionedSecret(this.backend, 'nu_ke', 'foo', 'bar', 2);
-      await runCmd(deleteLatestCmd(this.backend, 'nu_ke'));
+      await writeVersionedSecret(this.backend, 'nuke', 'foo', 'bar', 2);
+      await runCmd(deleteLatestCmd(this.backend, 'nuke'));
       // login as data-reader persona
       const token = await runCmd(makeToken('data-reader', this.backend, personas.dataReader));
-      await login(token);
-      clearRecords(this.store);
-      return;
+      return login(token);
     });
     test('cannot delete and undelete the latest secret version (dr)', async function (assert) {
       assert.expect(9);
@@ -207,7 +203,7 @@ module('Acceptance | kv-v2 workflow | delete, undelete, destroy', function (hook
       assert.dom(PAGE.infoRow).exists('shows secret data');
 
       // data-reader can't delete, so check undelete with already-deleted version
-      await visit(`/vault/secrets/${this.backend}/kv/nu_ke/details`);
+      await visit(`/vault/secrets/${this.backend}/kv/nuke/details`);
       assertDeleteActions(assert, []);
       assert
         .dom(PAGE.emptyStateTitle)
@@ -231,7 +227,7 @@ module('Acceptance | kv-v2 workflow | delete, undelete, destroy', function (hook
     });
     test('cannot permanently delete all secret versions (dr)', async function (assert) {
       // go to secret details
-      await visit(`/vault/secrets/${this.backend}/kv/nu_ke/details`);
+      await visit(`/vault/secrets/${this.backend}/kv/nuke/details`);
       // Check metadata toolbar
       await click(PAGE.secretTab('Metadata'));
       assert.dom(PAGE.metadata.deleteMetadata).doesNotExist('does not show delete metadata button');
@@ -242,13 +238,11 @@ module('Acceptance | kv-v2 workflow | delete, undelete, destroy', function (hook
     hooks.beforeEach(async function () {
       // create and delete a secret as root user
       await login();
-      await writeVersionedSecret(this.backend, 'nu_ke', 'foo', 'bar', 2);
-      await runCmd(deleteLatestCmd(this.backend, 'nu_ke'));
+      await writeVersionedSecret(this.backend, 'nuke', 'foo', 'bar', 2);
+      await runCmd(deleteLatestCmd(this.backend, 'nuke'));
       // login as data-list-reader persona
       const token = await runCmd(makeToken('data-list-reader', this.backend, personas.dataListReader));
-      await login(token);
-      clearRecords(this.store);
-      return;
+      return login(token);
     });
     test('can delete and cannot undelete the latest secret version (dlr)', async function (assert) {
       assert.expect(12);
@@ -295,7 +289,7 @@ module('Acceptance | kv-v2 workflow | delete, undelete, destroy', function (hook
     });
     test('cannot permanently delete all secret versions (dlr)', async function (assert) {
       // go to secret details
-      await visit(`/vault/secrets/${this.backend}/kv/nu_ke/details`);
+      await visit(`/vault/secrets/${this.backend}/kv/nuke/details`);
       // Check metadata toolbar
       await click(PAGE.secretTab('Metadata'));
       assert.dom(PAGE.metadata.deleteMetadata).doesNotExist('does not show delete metadata button');
@@ -306,13 +300,11 @@ module('Acceptance | kv-v2 workflow | delete, undelete, destroy', function (hook
     hooks.beforeEach(async function () {
       // create and delete a secret as root user
       await login();
-      await writeVersionedSecret(this.backend, 'nu_ke', 'foo', 'bar', 2);
-      await runCmd(deleteLatestCmd(this.backend, 'nu_ke'));
+      await writeVersionedSecret(this.backend, 'nuke', 'foo', 'bar', 2);
+      await runCmd(deleteLatestCmd(this.backend, 'nuke'));
       // login as metadata-maintainer persona
       const token = await runCmd(makeToken('metadata-maintainer', this.backend, personas.metadataMaintainer));
-      await login(token);
-      clearRecords(this.store);
-      return;
+      return login(token);
     });
     test('cannot delete but can undelete the latest secret version (mm)', async function (assert) {
       assert.expect(18);
@@ -328,7 +320,7 @@ module('Acceptance | kv-v2 workflow | delete, undelete, destroy', function (hook
       assert.dom(PAGE.detail.deleteOptionLatest).isDisabled('delete latest option is disabled');
 
       // Can't delete latest, try with pre-deleted secret
-      await visit(`/vault/secrets/${this.backend}/kv/nu_ke/details`);
+      await visit(`/vault/secrets/${this.backend}/kv/nuke/details`);
       assert.dom(PAGE.emptyStateTitle).hasText('You do not have permission to read this secret');
       assert.dom(PAGE.detail.versionTimestamp).doesNotExist('Version 2 timestamp not rendered');
       // updated toolbar options
@@ -397,7 +389,7 @@ module('Acceptance | kv-v2 workflow | delete, undelete, destroy', function (hook
     });
     test('cannot permanently delete all secret versions (mm)', async function (assert) {
       // go to secret details
-      await visit(`/vault/secrets/${this.backend}/kv/nu_ke/details`);
+      await visit(`/vault/secrets/${this.backend}/kv/nuke/details`);
       // Check metadata toolbar
       await click(PAGE.secretTab('Metadata'));
       assert.dom(PAGE.metadata.deleteMetadata).doesNotExist('does not show delete metadata button');
@@ -409,18 +401,16 @@ module('Acceptance | kv-v2 workflow | delete, undelete, destroy', function (hook
       const token = await runCmd(
         makeToken('secret-nested-creator', this.backend, personas.secretNestedCreator)
       );
-      await login(token);
-      clearRecords(this.store);
-      return;
+      return login(token);
     });
     test('can delete all secret versions from the nested list view (snc)', async function (assert) {
       assert.expect(1);
       // go to nested secret directory list view
       await visit(`/vault/secrets/${this.backend}/kv/list/app/nested`);
       // correct popup menu items appear on list view
-      const popupSelector = `${PAGE.list.item('bad_secret')} ${PAGE.popup}`;
+      const popupSelector = `${PAGE.list.item('bad-secret')} ${PAGE.popup}`;
       await click(popupSelector);
-      assert.dom(PAGE.list.listMenuDelete).exists('shows the option to permanently delete');
+      assert.dom(PAGE.list.menuItem('Permanently delete')).exists('shows the option to permanently delete');
     });
     test('can not delete all secret versions from root list view (snc)', async function (assert) {
       assert.expect(1);
@@ -434,9 +424,7 @@ module('Acceptance | kv-v2 workflow | delete, undelete, destroy', function (hook
   module('secret-creator persona', function (hooks) {
     hooks.beforeEach(async function () {
       const token = await runCmd(makeToken('secret-creator', this.backend, personas.secretCreator));
-      await login(token);
-      clearRecords(this.store);
-      return;
+      return login(token);
     });
     test('cannot delete and undelete the latest secret version (sc)', async function (assert) {
       assert.expect(9);
@@ -447,7 +435,7 @@ module('Acceptance | kv-v2 workflow | delete, undelete, destroy', function (hook
       assert.dom(PAGE.emptyStateTitle).hasText('You do not have permission to read this secret');
 
       // test with already deleted method
-      await visit(`/vault/secrets/${this.backend}/kv/nu_ke/details`);
+      await visit(`/vault/secrets/${this.backend}/kv/nuke/details`);
       assert.dom(PAGE.emptyStateTitle).hasText('You do not have permission to read this secret');
       assert.dom(PAGE.detail.versionTimestamp).doesNotExist('version timestamp not rendered');
       // updated toolbar options
@@ -469,9 +457,9 @@ module('Acceptance | kv-v2 workflow | delete, undelete, destroy', function (hook
       assertDeleteActions(assert, []);
     });
     test('can permanently delete all secret versions (sc)', async function (assert) {
-      await writeVersionedSecret(this.backend, 'nu_ke', 'foo', 'bar', 2);
+      await writeVersionedSecret(this.backend, 'nuke', 'foo', 'bar', 2);
       // go to secret details
-      await visit(`/vault/secrets/${this.backend}/kv/nu_ke/details`);
+      await visit(`/vault/secrets/${this.backend}/kv/nuke/details`);
       // Check metadata toolbar
       await click(PAGE.secretTab('Metadata'));
       assert.dom(PAGE.metadata.deleteMetadata).hasText('Permanently delete', 'shows delete metadata button');
@@ -520,9 +508,7 @@ path "sys/control-group/request" {
 
       const { userToken } = await setupControlGroup({ userPolicy, backend: this.backend });
       this.userToken = userToken;
-      await login(userToken);
-      clearRecords(this.store);
-      return;
+      return login(userToken);
     });
     // Copy test outline from admin persona
   });
